try:
    import pg8000 as pgdb
    class PostgresqlDb:
        @classmethod
        def conn_string(cls, dbname, hostname, port, username, password):
            s = 'dbname=%s host=%s port=%s user=%s password=%s' % (
                dbname,
                hostname,
                port,
                username,
                password,
                )
            return s

        def __init__(self, dbname, hostname, port, username, password):
            self.conn = None
            self.cursor = None
            conn_s = self.conn_string(dbname, hostname, port, username, password)
            self.conn = pgdb.connect(
                database=dbname,
                host=hostname,
                port=port,
                user=username,
                password=password,
                sslmode='prefer',
                )
            self.new_cursor()

        def __del__(self):
            if self.cursor:
                self.cursor.close()
            if self.conn:
                self.conn.close()

        def new_cursor(self):
            if self.cursor:
                self.cursor.close()
            self.cursor = self.conn.cursor()

        def execute(self, stmt, args=[]):
            self.cursor.execute(stmt, args)

        def fetch_list(self):
            out = []
            out = self.cursor.fetchall()
            self.new_cursor()
            return out

        def commit(self):
            '''
            COMMIT statement actually ends the transaction,
            which causes named portal objects to be destroyed.

            COMMIT is equivalent to END. Refer to
            http://www.postgresql.org/docs/9.3/static/sql-end.html
            '''
            self.conn.commit()
except ImportError:
    raise ImportError('Package pg8000 must be installed in order to use PostgresqlDb.')
