from tornadokick.web import Application, RequestHandler


class MyRequestHandler(RequestHandler):
    @classmethod
    def route(cls):
        return [
            r'/p[/]?',
            r'/p/([0-9]+)?',
            r'/parameter/([0-9]+)?',
        ]

    def get(self, status=None):
        if status is None:
            status = 0
        msg = {
            'parameter':int(status),
        }
        self.write_json(msg)


class StatusRequestHandler(RequestHandler):
    @classmethod
    def route(cls):
        return '/status[/]?'

    @classmethod
    def template_filename(cls):
        return 'status.html'

    def get(self):
        self.set_template_context_key('status', 'Welcome to Tornado Kick.')
        # Renders the template to user agent.
        self.template_render()


def main():
    from os.path import dirname, join
    handlers = [
        MyRequestHandler,
        StatusRequestHandler,
    ]
    static_paths = {
        # Path is relative to os.getcwd().
        r'/static':'static',
    }
    template_root = join(dirname(__file__), 'views')
    settings = {
        'template_path':template_root,
    }
    app = Application(handlers, static_paths, **settings)
    app.listen(8888)
    # Starts Tornado IO loop
    print('Running Tornado Kick example application')
    app.start()
