from .json import JSONFile
import datetime
import hashlib


class Base(JSONFile):
    def __init__(self):
        self.id = ''
        self.set_created_at()
        self.set_updated_at()
        super().__init__()

    def set_created_at(self):
        self.created_at = datetime.datetime.now()

    def set_updated_at(self):
        self.updated_at = datetime.datetime.now()

    def parse(self, d_obj):
        '''
        Parses a plain dictionary object into the object.
        '''
        for k, v in d_obj.items():
            setattr(self, k, v)


class User(Base):
    SALT = 'ThisSaltShouldBeOverridden'

    @classmethod
    def hash_password(cls, plaintext):
        combined = '%s%s%s' % (cls.SALT, plaintext, cls.SALT)
        combined = combined.encode()
        return hashlib.sha256(combined).hexdigest()

    def __init__(self):
        self.username = ''
        self.password_hash = ''
        super().__init__()

    def password_match(self, plaintext):
        h = self.hash_password(plaintext)
        return h == self.password_hash

    @property
    def password(self):
        return self.password_hash

    @password.setter
    def password(self, plaintext):
        self.password_hash = self.hash_password(plaintext)


class Session(JSONFile):
    '''
    Represents a login session.

    Override the COOKIE_NAME and DURATION to change
    the name of the cookie and duration before expiry respectively.
    '''

    COOKIE_NAME = 'tornadokick-session-id'
    DURATION = datetime.timedelta(days=1)

    def __init__(self, obj=None):
        self.id = ''
        self.user_id = ''
        self._flash_messages = []
        self.since = datetime.datetime.now()
        if obj:
            super().__init__(obj)

    def is_expired(self):
        now = datetime.datetime.now()
        duration = now - self.since
        return duration > self.DURATION

    def touch(self):
        self.since = datetime.datetime.now()

    def init_flash_messages(self):
        self._flash_messages = []

    def add_flash_message(self, msg):
        if type(msg) == list:
            for m in msg:
                self.add_flash_message(m)
            return
        self._flash_messages.append(msg)

    def flash_messages(self):
        '''
        Once retrieved, all flash messages will be removed.
        '''
        out = self._flash_messages
        self.init_flash_messages()
        return out

    def set_cookie(self, request_handler):
        request_handler.set_cookie(self.COOKIE_NAME, self.id)
